summaryrefslogtreecommitdiffstats
path: root/korn/maildrop.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korn/maildrop.cpp')
-rw-r--r--korn/maildrop.cpp56
1 files changed, 28 insertions, 28 deletions
diff --git a/korn/maildrop.cpp b/korn/maildrop.cpp
index 7a1dd444..9d2f12f6 100644
--- a/korn/maildrop.cpp
+++ b/korn/maildrop.cpp
@@ -6,7 +6,7 @@
*/
#include<assert.h>
-#include<qapplication.h>
+#include<tqapplication.h>
#include<kconfigbase.h>
#include<kdebug.h>
@@ -37,13 +37,13 @@ KMailDrop::KMailDrop()
: _style(Plain),
_lastCount(0)
{
- connect(this, SIGNAL(changed( int, KMailDrop* )), SLOT(setCount( int, KMailDrop* )));
+ connect(this, TQT_SIGNAL(changed( int, KMailDrop* )), TQT_SLOT(setCount( int, KMailDrop* )));
- //Set default colours; this prevents black (QColor::invalid) boxes after creating a new box.
- _bgColour = QApplication::palette().active().background();
- _fgColour = QApplication::palette().active().text();
- _nbgColour = QApplication::palette().active().background();
- _nfgColour = QApplication::palette().active().text();
+ //Set default colours; this prevents black (TQColor::invalid) boxes after creating a new box.
+ _bgColour = TQApplication::palette().active().background();
+ _fgColour = TQApplication::palette().active().text();
+ _nbgColour = TQApplication::palette().active().background();
+ _nfgColour = TQApplication::palette().active().text();
}
KMailDrop::~KMailDrop()
@@ -87,10 +87,10 @@ bool KMailDrop::readConfigGroup(const KConfigBase & c)
_caption = c.readEntry(fu(CaptionConfigKey));
_clickCmd = c.readPathEntry(fu(ClickConfigKey));
_style = Style(c.readUnsignedNumEntry(fu(DisplayStyleConfigKey), Plain));
- _bgColour = c.readColorEntry(fu(BgColourConfigKey), &QApplication::palette().active().background());
- _fgColour = c.readColorEntry(fu(FgColourConfigKey), &QApplication::palette().active().text());
- _nbgColour = c.readColorEntry(fu(NBgColourConfigKey), &QApplication::palette().active().background());
- _nfgColour = c.readColorEntry(fu(NFgColourConfigKey), &QApplication::palette().active().text());
+ _bgColour = c.readColorEntry(fu(BgColourConfigKey), &TQApplication::palette().active().background());
+ _fgColour = c.readColorEntry(fu(FgColourConfigKey), &TQApplication::palette().active().text());
+ _nbgColour = c.readColorEntry(fu(NBgColourConfigKey), &TQApplication::palette().active().background());
+ _nfgColour = c.readColorEntry(fu(NFgColourConfigKey), &TQApplication::palette().active().text());
_icon = c.readEntry(fu(IconConfigKey));
_nIcon = c.readEntry(fu(NewMailIconConfigKey));
_realName = c.readEntry(fu(RealNameConfigKey));
@@ -123,12 +123,12 @@ bool KMailDrop::writeConfigGroup(KConfigBase & c) const
return true;
}
-QValueVector<KornMailSubject> * KMailDrop::doReadSubjects(bool * /*stop*/)
+TQValueVector<KornMailSubject> * KMailDrop::doReadSubjects(bool * /*stop*/)
{
- return new QValueVector<KornMailSubject>(); // empty vector
+ return new TQValueVector<KornMailSubject>(); // empty vector
}
-QValueVector<KornMailSubject> * KMailDrop::readSubjects(bool * stop)
+TQValueVector<KornMailSubject> * KMailDrop::readSubjects(bool * stop)
{
// remember timer status
bool timerWasRunning = running();
@@ -138,7 +138,7 @@ QValueVector<KornMailSubject> * KMailDrop::readSubjects(bool * stop)
stopMonitor();
// read the subjects
- QValueVector<KornMailSubject> * result = doReadSubjects(stop);
+ TQValueVector<KornMailSubject> * result = doReadSubjects(stop);
int newcount = result->size();
// if the mail count has changed: notify the button!
@@ -154,35 +154,35 @@ QValueVector<KornMailSubject> * KMailDrop::readSubjects(bool * stop)
}
-bool KMailDrop::deleteMails(QPtrList<const KornMailId> * /*ids*/, bool * /*stop*/)
+bool KMailDrop::deleteMails(TQPtrList<const KornMailId> * /*ids*/, bool * /*stop*/)
{
return false;
}
-QString KMailDrop::readMail(const KornMailId * /*id*/, bool * /*stop*/)
+TQString KMailDrop::readMail(const KornMailId * /*id*/, bool * /*stop*/)
{
return "";
}
-void KMailDrop::setCaption(QString s)
+void KMailDrop::setCaption(TQString s)
{
_caption = s;
emit(configChanged());
}
-void KMailDrop::setClickCmd(QString s)
+void KMailDrop::setClickCmd(TQString s)
{
_clickCmd = s;
emit(configChanged());
}
-void KMailDrop::setNewMailCmd(QString s)
+void KMailDrop::setNewMailCmd(TQString s)
{
_nMailCmd = s;
emit(configChanged());
}
-void KMailDrop::setSoundFile(QString s)
+void KMailDrop::setSoundFile(TQString s)
{
_soundFile = s;
emit(configChanged());
@@ -194,37 +194,37 @@ void KMailDrop::setDisplayStyle(Style s)
emit(configChanged());
}
-void KMailDrop::setBgColour(QColor c)
+void KMailDrop::setBgColour(TQColor c)
{
_bgColour = c;
emit(configChanged());
}
-void KMailDrop::setFgColour(QColor c)
+void KMailDrop::setFgColour(TQColor c)
{
_fgColour = c;
emit(configChanged());
}
-void KMailDrop::setNewBgColour(QColor c)
+void KMailDrop::setNewBgColour(TQColor c)
{
_nbgColour = c;
emit(configChanged());
}
-void KMailDrop::setNewFgColour(QColor c)
+void KMailDrop::setNewFgColour(TQColor c)
{
_nfgColour = c;
emit(configChanged());
}
-void KMailDrop::setIcon(QString s)
+void KMailDrop::setIcon(TQString s)
{
_icon = s;
emit(configChanged());
}
-void KMailDrop::setNewIcon(QString s)
+void KMailDrop::setNewIcon(TQString s)
{
_nIcon = s;
emit(configChanged());
@@ -242,7 +242,7 @@ void KMailDrop::setPassiveDate( bool pd )
emit(configChanged());
}
-void KMailDrop::setRealName(QString str)
+void KMailDrop::setRealName(TQString str)
{
_realName = str;
}